/** 
 * 对日期进行格式化， 
 * @param date 要格式化的日期 
 * @param format 进行格式化的模式字符串
 *     支持的模式字母有： 
 *     y:年, 
 *     M:年中的月份(1-12), 
 *     d:月份中的天(1-31), 
 *     h:小时(0-23), 
 *     m:分(0-59), 
 *     s:秒(0-59), 
 *     S:毫秒(0-999),
 *     q:季度(1-4)
 * @return String
 * @author yanis.wang
 * @see	http://yaniswang.com/frontend/2013/02/16/dateformat-performance/
 */
template.helper('dateFormat', function (date, format) {

    date = new Date(date);

    var map = {
        "M": date.getMonth() + 1, //月份 
        "d": date.getDate(), //日 
        "h": date.getUTCHours(), //小时 
        "m": date.getMinutes(), //分 
        "s": date.getSeconds(), //秒 
        "q": Math.floor((date.getMonth() + 3) / 3), //季度 
        "S": date.getMilliseconds() //毫秒 
    };
    format = format.replace(/([yMdhmsqS])+/g, function(all, t){
        var v = map[t];
        if(v !== undefined){
            if(all.length > 1){
                v = '0' + v;
                v = v.substr(v.length-2);
            }
            return v;
        }
        else if(t === 'y'){
            return (date.getFullYear() + '').substr(4 - all.length);
        }
        return all;
    });
    return format;
});

template.helper('phone', function (value) {
	if(value.length == 11) return value.substring(0,3) + " " + value.substring(3,7) + " " + value.substring(7,11);
	return value;
});

template.helper('site', function (value) {
	return getPicUrl() + value;
});

template.helper('genderCss', function (value) {
    if(value == "男") return "fa-mars";
    if(value == "女") return "fa-venus";
    return "fa-genderless";
});

template.helper('taskCss', function (value) {
    if(value == "推客") return "task-reco";
    if(value == "带看") return "task-visit";
    if(value == "认筹") return "task-chip";
    if(value == "认购") return "task-order";
    if(value == "成交") return "task-close";
    return "-";
});

template.helper('taskStatusCss', function (value) {
    if(value == "流失") return "task-missing";
    if(value == "待审批") return "task-approval";
    if(value == "有效") return "task-valid";
    if(value == "无效") return "task-invalid";
    return "-";
});

template.helper('taskUrl', function (value) {
    if(value.Type == "推客") return value.Status == "有效" ? "main_task_see_apply.html?no=" + value.No :value.Status == "流失" ? "main_task_more_twitter.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "带看") return value.Status == "有效" ? "main_task_from_apply.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "认筹") return value.Status == "有效" ? "main_task_offer_apply.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "认购") return value.Status == "有效" ? "main_task_strike_apply.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "成交") return value.Status == "有效" ? "main_task_details.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    return "-";
});



template.helper('taskApproveUrl', function (value) {
    if(value.Type == "推客") return value.Status == "待审批" ? "main_task_outer.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "带看") return value.Status == "待审批" ? "main_task_approval.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "认筹") return value.Status == "待审批" ? "main_task_approval.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "认购") return value.Status == "待审批" ? "main_subscription.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    if(value.Type == "成交") return value.Status == "待审批" ? "main_task_deal.html?no=" + value.No : "main_task_details.html?no=" + value.No;
    return "-";
});
